@@ -8,15 +8,8 @@ from elifetools import xmlio
 from elifetools import utils as etoolsutils
 
 
-# namespaces for when reparsing XML strings
-XML_NAMESPACE_MAP = {
-    "ali": "http://www.niso.org/schemas/ali/1.0/",
-    "mml": "http://www.w3.org/1998/Math/MathML",
-    "xlink": "http://www.w3.org/1999/xlink",
-}
-
-# characters after maths italic and bold italic ones - U+1D49C to U+1D7C9
-MATH_SYMBOL_CHARS = [chr(char_num) for char_num in list(range(119964, 120777))]
+# characters after maths italic and bold italic ones - U+1D400 to U+1D7C9
+MATH_SYMBOL_CHARS = [chr(char_num) for char_num in list(range(119808, 120777))]
 
 # problem characters e.g. 8232 is a LINE SEPARATOR character
 PROBLEM_PUNCTUATION_CHARS = [chr(8232)]
@@ -24,14 +17,6 @@ PROBLEM_PUNCTUATION_CHARS = [chr(8232)]
 PROBLEM_CHARS = PROBLEM_PUNCTUATION_CHARS + MATH_SYMBOL_CHARS
 
 
-def reparsing_namespaces(namespace_map):
-    """compile a string representation of the namespaces"""
-    namespace_string = ""
-    for prefix, uri in namespace_map.items():
-        namespace_string += 'xmlns:%s="%s" ' % (prefix, uri)
-    return namespace_string.rstrip()
-
-
 def remove_non_breaking_space(string):
     """replace non breaking space characters"""
     return string.replace("\xc2\xa0", "").replace("\xa0", "") if string else ""
@@ -155,89 +140,6 @@ def clean_portion(string, root_tag="root"):
     return string.lstrip().rstrip()
 
 
-def allowed_tags():
-    """tuple of whitelisted tags"""
-    return (
-        "<p>",
-        "<p ",
-        "</p>",
-        "<disp-quote",
-        "</disp-quote>",
-        "<italic>",
-        "</italic>",
-        "<bold>",
-        "</bold>",
-        "<underline>",
-        "</underline>",
-        "<sub>",
-        "</sub>",
-        "<sup>",
-        "</sup>",
-        "<sc>",
-        "</sc>",
-        "<inline-formula>",
-        "</inline-formula>",
-        "<disp-formula>",
-        "</disp-formula>",
-        "<mml:",
-        "</mml:",
-        "<ext-link",
-        "</ext-link>",
-        "<list>",
-        "<list ",
-        "</list>",
-        "<list-item",
-        "</list-item>",
-        "<label>",
-        "</label>",
-        "<title>",
-        "</title>",
-        "<caption>",
-        "</caption>",
-        "<graphic ",
-        "</graphic>",
-        "<table",
-        "<table ",
-        "</table>",
-        "<thead>",
-        "</thead>",
-        "<tbody>",
-        "</tbody>",
-        "<tr>",
-        "</tr>",
-        "<th>",
-        "<th",
-        "</th>",
-        "<td>",
-        "<td ",
-        "</td>",
-        "<xref ",
-        "</xref>",
-    )
-
-
-def append_to_parent_tag(
-    parent,
-    tag_name,
-    original_string,
-    namespace_map,
-    attributes=None,
-    attributes_text="",
-):
-    """escape and reparse the string then add it to the parent tag"""
-    tag_converted_string = etoolsutils.escape_ampersand(original_string)
-    tag_converted_string = etoolsutils.escape_unmatched_angle_brackets(
-        tag_converted_string, allowed_tags()
-    )
-    namespaces_string = reparsing_namespaces(namespace_map)
-    minidom_tag = xmlio.reparsed_tag(
-        tag_name, tag_converted_string, namespaces_string, attributes_text
-    )
-    xmlio.append_minidom_xml_to_elementtree_xml(
-        parent, minidom_tag, attributes=attributes, child_attributes=True
-    )
-
-
 def xml_string_fix_namespaces(xml_string, root_tag):
     """due to some bug with ElementTree.tostring, remove duplicate namespace attributes"""
     # remove duplicate namespaces from root tag e.g. xmlns:mml="http://www.w3.org/1998/Math/MathML
@@ -399,18 +301,3 @@ def remove_complex_scripts_styles(document_xml):
         new_document_xml += xml_part
 
     return new_document_xml
-
-
-def object_id_from_uri(uri):
-    """
-    from a sciety.org uri extract the DOI portion to be an id value
-    e.g. from https://sciety.org/articles/activity/10.1101/865006
-    return 10.1101/865006
-    """
-    if uri:
-        id_match_pattern = re.compile(r".*?/(10\..*)")
-        matches = id_match_pattern.match(uri)
-        if matches:
-            return matches.group(1)
-        return uri
-    return uri
